BasicFlagExtensionCopyWith<T extends BasicFlag> extension

An extension on BasicFlag to provide a copyWith method for creating a new instance of BasicFlag with modified properties.

This extension allows you to create a new BasicFlag by copying the existing one and overriding specific properties.

Example usage:

final newFlag = existingFlag.copyWith(aspectRatio: 1.5);
on
  • T

Methods

copyWith({FlagProperties? properties, double? aspectRatio, BoxDecoration? decoration, DecorationPosition? decorationPosition, EdgeInsetsGeometry? padding, FlagPainterBuilder<CustomPainter>? elementsBuilder, CustomPainter? backgroundPainter, CustomPainter? foregroundPainter, FlagPainterBuilder<CustomPainter>? foregroundPainterBuilder, FlagWidgetBuilder<Widget>? foregroundWidgetBuilder, double? height, double? width, Widget? child, Key? key}) BasicFlag

Available on T, provided by the BasicFlagExtensionCopyWith extension

Creates a copy of this BasicFlag but with the given fields replaced with the new values.
copyWithTheme({FlagProperties? properties, FlagThemeData? theme, FlagPainterBuilder<CustomPainter>? elementsBuilder, CustomPainter? backgroundPainter, CustomPainter? foregroundPainter, FlagPainterBuilder<CustomPainter>? foregroundPainterBuilder, FlagWidgetBuilder<Widget>? foregroundWidgetBuilder, Key? key}) BasicFlag

Available on T, provided by the BasicFlagExtensionCopyWith extension

Creates a copy of this BasicFlag but with the given fields replaced with the new values.