decimalMark property
The decimal mark, or character used to separate the whole unit from the subunit.
Implementation
final String decimalMark;
The decimal mark, or character used to separate the whole unit from the subunit.
final String decimalMark;