DecoratedFlagWidget class abstract

An abstract widget that displays a flag for a given object.

The DecoratedFlagWidget widget can be used to a flag. It supports various customization options such as height, width, aspect ratio, decoration (and its position), padding, and a child widget.

Inheritance
Implemented types
Implementers
Available extensions

Constructors

DecoratedFlagWidget({double? aspectRatio, BoxDecoration? decoration, DecorationPosition? decorationPosition, EdgeInsetsGeometry? padding, double? height, double? width, Widget? child, Key? key})
Creates a DecoratedFlagWidget widget with a simple flag representation.
const

Properties

aspectRatio double?
The specified aspect ratio of the flag.
final
calculatedAspectRatio double?

Available on DecoratedFlagInterface, provided by the DecoratedFlagInterfaceExtension extension

The calculated aspect ratio of the flag based on its width and height.
no setter
child Widget?
A widget to display in the foreground of the flag.
final
decoration BoxDecoration?
The decoration of the flag.
final
decorationPosition DecorationPosition?
The position of the decoration.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
The height of the flag.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
The padding around the flag.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
The width of the flag.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
toThemeData({Widget? child}) FlagThemeData

Available on DecoratedFlagInterface, provided by the DecoratedFlagInterfaceExtension extension

Converts this DecoratedFlagInterface to a FlagThemeData instance.

Operators

operator ==(Object other) bool
The equality operator.
inherited