Dravidian class final

A class that represents the Dravidian language family.

Inheritance

Constructors

Dravidian()
Creates an instance of the Dravidian language family.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the language family.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) String
Returns a string representation of this LanguageFamily object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited