properties property

ElementsProps get properties

Retrieves the properties of the elements to be painted.

If no properties are provided, this returns an empty list.

Implementation

ElementsProps get properties => _properties ?? const [];