FiatCurrencyFormat extension

Provides a set of methods for formatting values of FiatCurrency.

on

Methods

addUnit(String value, {bool isRtl = false}) String

Available on FiatCurrency, provided by the FiatCurrencyFormat extension

Adds the currency unit to a value.
format(num value, {bool isRtl = false}) String

Available on FiatCurrency, provided by the FiatCurrencyFormat extension

Formats the value as a string with the currency symbol. Please keep in mind that currency formatting might be also affected by locale itself.
tryFormat([num? maybeValue, bool isRtl = false]) String?

Available on FiatCurrency, provided by the FiatCurrencyFormat extension

If value is not null - formats the value as a string with the currency symbol. Otherwise returns null.