FiatTzs class final

A class that represents the Tanzanian Shilling currency.

Inheritance
Available extensions

Constructors

FiatTzs()
Creates a instance of FiatTzs (Tanzanian Shilling currency).
const
factory

Properties

alternateSymbols List<String>?
Alternative symbols for this currency or null if no such symbols exists.
finalinherited
code String
The standardized code for the currency.
finalinherited
codeNumeric String
The international 3-numeric non-empty numeric code as defined by the ISO 4217 standard.
finalinherited
codeOther String
The international 3-numeric non-empty numeric code as defined by the ISO 4217 standard.
no setterinherited
decimalMark String
The decimal mark, or character used to separate the whole unit from the subunit.
finalinherited
disambiguateSymbol String?
Alternative currency used if symbol is ambiguous, or null if no such symbol exists.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
htmlEntity String?
The HTML entity for the currency symbol, or null if no such entity exists.
finalinherited
internationalName String
An String representing the international name of the object. This is typically a English name of the ISO object.
no setterinherited
iso4217Letter String

Available on FiatCurrency, provided by the FiatCurrencyGetters extension

Returns the ISO 4217 letter code of the currency.
no setter
iso4217Numeric String

Available on FiatCurrency, provided by the FiatCurrencyGetters extension

Returns the ISO 4217 numeric code of the currency.
no setter
l10n LocalizationDelegate
Returns the BasicLocalizationDelegate used for handling translations.
no setterinherited
name String
The name of the currency.
finalinherited
namesNative List<String>
The native names of the currency in different locales.
finalinherited
priority int
A numerical value that can be used to sort/group any currency list.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smallestDenomination int
Smallest amount of cash possible (in the subunit of this currency).
finalinherited
subunit String?
The name of the fractional monetary unit, or null if no such name exists.
finalinherited
subunitToUnit int
The proportion between the unit and the subunit.
finalinherited
symbol String?
The currency symbol.
finalinherited
thousandsSeparator String
The character used to separate thousands grouping of the whole unit.
finalinherited
unit String

Available on FiatCurrency, provided by the FiatCurrencyGetters extension

Returns the unit of the currency.
no setter
unitFirst bool
Should the currency symbol precede the amount, or should it come after?
finalinherited

Methods

addUnit(String value, {bool isRtl = false}) String

Available on FiatCurrency, provided by the FiatCurrencyFormat extension

Adds the currency unit to a value.
compareTo(FiatCurrency other) int
Compares this object to another object.
inherited
copyWith({List<String>? alternateSymbols, String? code, String? codeNumeric, String? decimalMark, String? disambiguateSymbol, String? htmlEntity, String? name, List<String>? namesNative, int? priority, int? smallestDenomination, String? subunit, int? subunitToUnit, String? symbol, String? thousandsSeparator, LocaleMapFunction<String> mapper()?, bool? unitFirst}) FiatCurrency

Available on T, provided by the FiatCurrencyCopyWith extension

Creates a new instance of FiatCurrency with updated properties.
format(num value, {bool isRtl = false}) String

Available on FiatCurrency, provided by the FiatCurrencyFormat extension

Formats the value as a string with the currency symbol. Please keep in mind that currency formatting might be also affected by locale itself.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({JsonCodec codec = const JsonCodec()}) String
Returns a JSON-encoded string representation of the object.
inherited
toMap() Map<String, Object>

Available on FiatCurrency, provided by the FiatCurrencyJson extension

Converts this object object to a JSON like map.
toString({bool short = true}) String
Returns a string representation of this instance.
inherited
tryFormat([num? maybeValue, bool isRtl = false]) String?

Available on FiatCurrency, provided by the FiatCurrencyFormat extension

If value is not null - formats the value as a string with the currency symbol. Otherwise returns null.

Operators

operator ==(Object other) bool
The equality operator.
inherited