ImnPainter class final
Painter for the Isle of Man flag.
- Inheritance
Constructors
- ImnPainter(ElementsProps? properties, double aspectRatio)
-
Creates a new instance of ImnPainter.
const
Properties
- aspectRatio → double
-
The aspect ratio of the flag.
finalinherited
-
customColors
→ List<
Color> -
Retrieves the custom colors of the elements to be painted.
no setterinherited
- customProperties → CustomElementsProperties
-
Retrieves the custom properties of the elements to be painted.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalAspectRatio → double
-
The original aspect ratio of the flag.
no setteroverride
- properties → ElementsProps
-
Retrieves the properties of the elements to be painted.
no setterinherited
- property → ElementsProperties
-
Retrieves the first property from the list of properties.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsBuilder → SemanticsBuilderCallback?
-
Returns a function that builds semantic information for the picture drawn
by this painter.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be notified when it is time to repaint.
inherited
-
calculateAspectRatio(
Size size) → double -
Calculates the aspect ratio of the element based on the provided
size.inherited -
calculateCenter(
Size size) → Offset -
Calculates the center offset of the element based on the provided
size.inherited -
calculateSize(
Size size) → double -
Calculates the size of the element based on the provided
size.inherited -
hitTest(
Offset position) → bool? -
Called whenever a hit test is being performed on an object that is using
this custom paint delegate.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → FlagParentBounds? -
Paints the flag elements on the given canvas and size.
inherited
-
paintChild(
Canvas canvas, Rect parentBounds, ElementsProperties? child) → FlagParentBounds? -
Paints a child element on the given canvas within the specified parent
bounds.
inherited
-
paintCreator(
[Color? color]) → Paint -
Creates a Paint object with the specified
color.inherited -
painter(
Shape child) → ElementsPainter Function(ElementsProps?, double) -
Retrieves the appropriate painter for the given child shape.
inherited
-
paintFlagElements(
Canvas canvas, Size size) → FlagParentBounds -
Paints the flag elements on the given canvas and size.
override
-
ratioAdjustedSize(
Size size, {double minRatio = 1.1}) → Size -
Adjusts the size of the child element based on the aspect ratio.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies when it is time to repaint.
inherited
-
shapeType<
T extends Shape> ([Shape? shape]) → T? -
Retrieves the shape type if it matches the specified type
T.inherited -
shouldRebuildSemantics(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
shouldRepaint(
covariant CustomPainter oldDelegate) → bool -
Called whenever a new instance of the custom painter delegate class is
provided to the RenderCustomPaint object, or any time that a new
CustomPaint object is created with a new instance of the custom painter
delegate class (which amounts to the same thing, because the latter is
implemented in terms of the former).
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited