LocaleMappingOptionsExtension<T extends Object> extension

Extension methods for LocaleMappingOptions class.

Type parameter T represents the type of locale identifier that can be used for main and fallback locales.

on

Methods

copyWith({String? altSymbol, T? fallbackLocale, bool? localizeFullNames, T? mainLocale, bool? useLanguageFallback, String formatter(IsoLocaleKey isoLocale, String l10n)?}) LocaleMappingOptions<T>

Available on LocaleMappingOptions<T>, provided by the LocaleMappingOptionsExtension extension

Creates a copy of this LocaleMappingOptions with the given fields replaced.