Micronesia class final

Represents the Micronesia region, which includes the countries of Federated States of Micronesia, Guam, Kiribati, Marshall Islands, Nauru, etc.

This class extends SubRegion and sets its name property to "Micronesia".

Example:

final micronesia = Micronesia();
print(micronesia.name); // "Micronesia"
Inheritance

Constructors

Micronesia()
Creates a new Micronesia instance.
const

Properties

continent Continent
The parent continent that owns this subregion.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the region.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited