SouthAmerica class final

Represents the South America region, which includes the countries of Argentina, Bolivia, Brazil, Chile, Colombia, etc.

This class extends SubRegion and sets its name property to "South America".

Example:

final southAmerica = SouthAmerica();
print(southAmerica.name); // "South America"
Inheritance

Constructors

SouthAmerica()
Creates a new SouthAmerica instance.
const

Properties

continent Continent
The parent continent that owns this subregion.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the region.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited