WesternEurope class final

Represents the Western Europe region, which includes the countries of Austria, Belgium, France, Germany, Netherlands, Switzerland, etc.

This class extends SubRegion and sets its name property to "Western Europe".

Example:

import 'package:sealed_countries/sealed_countries.dart';

void main() {
  const westernEurope = WesternEurope();
  assert(westernEurope.name == 'Western Europe');
}
Inheritance

Constructors

WesternEurope()
Creates a new WesternEurope instance.
const

Properties

continent → Continent
The parent continent that owns this subregion.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the region.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited