CountryIdn class
A class that represents the Indonesia country.
- Inheritance
-
- Object
- Country
- WorldCountry
- CountryIdn
- Available extensions
Constructors
- CountryIdn()
-
Creates a instance of CountryIdn (Indonesia country).
constfactory
Properties
-
altSpellings
→ List<
String> -
The alternate spellings of the country name.
finalinherited
- areaImperial → double
-
Available on WorldCountry, provided by the WorldCountryGeo extension
Returns the area of the country in square miles.no setter - areaMetric → double
-
The area of the country in square kilometers.
finalinherited
-
borders
→ List<
WorldCountry> ? -
Available on WorldCountry, provided by the WorldCountryGeo extension
Returns an unmodifiable list of WorldCountry objects representing the countries that share a land border with this country.no setter -
bordersCodes
→ List<
String> ? -
The codes of the countries that share borders with this country.
finalinherited
- capitalInfo → CapitalInfo
-
The capital city information of the country.
no setteroverride
- car → Car
-
The car information of the country.
finalinherited
- cioc → String?
-
The International Olympic Committee code of the country.
finalinherited
- code → String
-
The three-letter ISO 3166-1 Alpha-3 code of the country.
finalinherited
- codeNumeric → String
-
The three-digit ISO 3166-1 Numeric code of the country.
finalinherited
- codeOther → String
-
The two-letter ISO 3166-1 Alpha-2 code of the country.
no setterinherited
- codeShort → String
-
The two-letter ISO 3166-1 Alpha-2 code of the country.
finalinherited
- continent → Continent
-
The continent where the country is located.
finalinherited
-
currencies
→ List<
FiatCurrency> -
The currencies used in the country.
no setteroverride
-
demonyms
→ List<
Demonyms> -
The demonym names for the people of the country.
no setteroverride
- emoji → String
-
The emoji flag for the country.
finalinherited
- fifa → String?
-
The FIFA code of the country.
finalinherited
-
flagColors
→ List<
Color> -
Available on WorldCountry, provided by the FlagExtension extension
Combines flagStripeColors and flagElementsColors into a single list of colors.no setter -
flagElementsColors
→ List<
Color> -
Available on WorldCountry, provided by the FlagExtension extension
Retrieves the element colors of the flag from FlagProperties. If the elements have custom properties, their additional colors are included.no setter - flagProperties → FlagProperties?
-
Available on WorldCountry, provided by the FlagExtension extension
Retrieves the FlagProperties associated with the default WorldCountry.no setter -
flagStripeColors
→ List<
Color> -
Available on WorldCountry, provided by the FlagExtension extension
Retrieves the stripe colors of the flag from FlagProperties.no setter - gini → Gini?
-
The Gini coefficient of the country.
finalinherited
- hasCoatOfArms → bool
-
Whether the country has an official coat of arms.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- idd → Idd
-
The international direct dialing codes for the country.
finalinherited
- independent → bool
-
Whether the country is an independent state.
finalinherited
- internationalName → String
-
An String representing the international name of the object. This is
typically a English name of the ISO object.
no setterinherited
- iso3166oneAlpha2 → String
-
Available on WorldCountry, provided by the WorldCountryGetters extension
Returns the ISO 3166-1 Alpha-2 code of country.no setter - iso3166oneAlpha3 → String
-
Available on WorldCountry, provided by the WorldCountryGetters extension
Returns the ISO 3166-1 Alpha-3 code of country.no setter - iso3166oneNumeric → String
-
Available on WorldCountry, provided by the WorldCountryGetters extension
Returns the ISO 3166-1 Numeric code of country.no setter - isOfficiallyAssigned → bool
-
Available on WorldCountry, provided by the WorldCountryGetters extension
Returnstrueif this WorldCountry object is officially assigned.no setter - l10n → TypedLocalizationDelegate
-
Returns the BasicLocalizationDelegate used for handling translations.
no setterinherited
- landlocked → bool
-
Whether the country is landlocked.
finalinherited
-
languages
→ List<
NaturalLanguage> -
The official languages spoken in the country.
no setteroverride
- latLng → LatLng
-
The geographic coordinates of the country.
finalinherited
- maps → Maps
-
The maps of the country.
finalinherited
- name → CountryName
-
The name of the country.
finalinherited
-
namesNative
→ List<
CountryName> -
The native names of the country.
no setteroverride
- population → int
-
The population of the country.
finalinherited
- postalCode → PostalCode?
-
The postal code information of the country.
finalinherited
-
regionalBlocs
→ List<
RegionalBloc> -
The regional blocs of the country.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startOfWeek → Weekday
-
The first day of the week in the country.
finalinherited
- subregion → SubRegion?
-
The subregion where the country is located.
finalinherited
-
timezones
→ List<
String> -
The time zones of the country.
finalinherited
-
tld
→ List<
String> -
The top level domain names for the country.
finalinherited
-
tzUtcDurations
→ List<
UtcDurationDifference> -
Available on WorldCountry, provided by the WorldCountryDateTime extension
Returns an unmodifiable list of UtcDurationDifference objects representing the time differences between Coordinated Universal Time (UTC) and the time zones in the timezones list of the WorldCountry object.no setter - unMember → bool
-
Whether the country is a member of the United Nations.
finalinherited
Methods
-
compareTo(
WorldCountry other) → int -
Compares this object to another object.
inherited
-
copyWith(
{CountryName? name, List< CountryName> ? namesNative, List<String> ? tld, String? code, String? codeNumeric, String? codeShort, String? cioc, bool? independent, bool? unMember, List<FiatCurrency> ? currencies, Idd? idd, List<String> ? altSpellings, Continent? continent, SubRegion? subregion, List<NaturalLanguage> ? languages, LatLng? latLng, bool? landlocked, List<String> ? bordersCodes, double? areaMetric, List<Demonyms> ? demonyms, String? emoji, Maps? maps, int? population, Gini? gini, String? fifa, Car? car, List<String> ? timezones, bool? hasCoatOfArms, Weekday? startOfWeek, CapitalInfo? capitalInfo, PostalCode? postalCode, List<RegionalBloc> ? regionalBlocs, LocaleMapFunction<String> mapper()?}) → WorldCountry -
Available on T, provided by the WorldCountryCopyWith extension
Creates a copy of this object with the given fields replaced with the new values. -
flagPngUrl(
) → String -
Available on WorldCountry, provided by the WorldCountryWebResources extension
Returns the URL of the PNG image file for the country's flag. -
flagSvgUrl(
) → String -
Available on WorldCountry, provided by the WorldCountryWebResources extension
Returns the URL of the SVG image file for the country's flag. -
maybeCoatOfArmsPngUrl(
) → String? -
Available on WorldCountry, provided by the WorldCountryWebResources extension
Returns the URL of the PNG image file for the country's coat of arms if it has one, ornullotherwise. -
maybeCoatOfArmsSvgUrl(
) → String? -
Available on WorldCountry, provided by the WorldCountryWebResources extension
Returns the URL of the SVG image file for the country's coat of arms if it has one, ornullotherwise. -
namesOfficialNative(
{String separator = "/", bool skipFirst = false, String? orElse}) → String -
Available on WorldCountry, provided by the WorldCountryNames extension
Returns the official and native names of the country as a single string. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{JsonCodec codec = const JsonCodec()}) → String -
Returns a JSON-encoded string representation of the object.
inherited
-
toMap(
) → JsonObjectMap -
Available on WorldCountry, provided by the WorldCountryJson extension
Converts this object object to a JSON like map. -
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited