EasternEurope class final
Represents the Eastern Europe region, which includes the countries of Belarus, Poland, Romania, Russia, etc.
This class extends SubRegion and sets its name property to "Eastern Europe".
Example:
import 'package:sealed_countries/sealed_countries.dart';
void main() {
const easternEurope = EasternEurope();
assert(easternEurope.name == 'Eastern Europe');
}
Constructors
- EasternEurope()
-
Creates a new EasternEurope instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited