property property
Retrieves the first property from the list of properties.
This is a protected getter intended for use within subclasses.
Implementation
@protected
ElementsProperties get property => properties.first;
Retrieves the first property from the list of properties.
This is a protected getter intended for use within subclasses.
@protected
ElementsProperties get property => properties.first;