FlagParentBounds typedef
A type definition for a record that holds the parent bounds of a flag element.
The record contains the following fields:
canvas: The Canvas on which the flag element is drawn.bounds: The Rect that defines the bounds of the flag element.child: An optional ElementsProperties that defines the properties of the child element.
Implementation
typedef FlagParentBounds = ({
Rect bounds,
Canvas canvas,
ElementsProperties? child,
});