MapsExtension extension
Provides extension methods for Maps class.
Contains common methods for example copyWith, toMap, fromMap, etc,
that are common to all package's submodels.
- on
Properties
- googleMapsUrl → String
-
Available on Maps, provided by the MapsExtension extension
Returns the full Google Maps URL for this Maps object.no setter - openStreetMapsUrl → String
-
Available on Maps, provided by the MapsExtension extension
Returns the full OpenStreetMap URL for this Maps object.no setter
Methods
-
copyWith(
{String? googleMaps, String? openStreetMaps}) → Maps -
Available on Maps, provided by the MapsExtension extension
Creates a copy of this object with the given fields replaced with the new values. -
toMap(
) → Map< String, String> -
Available on Maps, provided by the MapsExtension extension
Converts this object object to a JSON like map.
Static Methods
-
fromMap(
JsonMap map) → Maps -
Available on Maps, provided by the MapsExtension extension
Creates a new instance of this object from a JSON like map.