Polynesia class final
Represents the Polynesia region, which includes the countries of American Samoa, Cook Islands, French Polynesia, Niue, etc.
This class extends SubRegion and sets its name property to "Polynesia".
Example:
final polynesia = Polynesia();
print(polynesia.name); // "Polynesia"
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited