SouthAmerica class final
Represents the South America region, which includes the countries of Argentina, Bolivia, Brazil, Chile, Colombia, etc.
This class extends SubRegion and sets its name property to "South America".
Example:
final southAmerica = SouthAmerica();
print(southAmerica.name); // "South America"
Constructors
- SouthAmerica()
-
Creates a new SouthAmerica instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited