SouthernAfrica class final
Represents the Southern Africa region, which includes the countries of Botswana, Eswatini (Swaziland), Lesotho, Namibia, South Africa, and Zimbabwe.
This class extends SubRegion and sets its name property to "Southern Africa".
Example:
import 'package:sealed_countries/sealed_countries.dart';
void main() {
const southernAfrica = SouthernAfrica();
assert(southernAfrica.name == 'Southern Africa');
}
Constructors
- SouthernAfrica()
-
Creates a new SouthernAfrica instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited