SouthernAfrica class

Represents the Southern Africa region, which includes the countries of Botswana, Eswatini (Swaziland), Lesotho, Namibia, South Africa, and Zimbabwe.

This class extends the Africa class and sets its name property to "Southern Africa".

Example:

final southernAfrica = SouthernAfrica();
print(southernAfrica.name); // "Southern Africa"
Inheritance
Available extensions

Constructors

SouthernAfrica()
Creates a new SouthernAfrica instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the region.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<R>({required R europe(Continent europe), required R africa(Continent africa), required R americas(Continent americas), required R asia(Continent asia), required R antarctica(Continent antarctica), required R oceania(Continent oceania)}) → R

Available on Continent, provided by the ContinentFunctional extension

maybeMap<R>({required R orElse(Continent continent), R europe(Continent europe)?, R africa(Continent africa)?, R americas(Continent americas)?, R asia(Continent asia)?, R antarctica(Continent antarctica)?, R oceania(Continent oceania)?}) → R

Available on Continent, provided by the ContinentFunctional extension

maybeWhen<R>({required R orElse(), R europe()?, R africa()?, R americas()?, R asia()?, R antarctica()?, R oceania()?}) → R

Available on Continent, provided by the ContinentFunctional extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool short = true}) String
A string representation of this object.
inherited
when<R>({required R europe(), required R africa(), required R americas(), required R asia(), required R antarctica(), required R oceania()}) → R

Available on Continent, provided by the ContinentFunctional extension

whenOrNull<R>({R europe()?, R africa()?, R americas()?, R asia()?, R antarctica()?, R oceania()?, R orElse()?}) → R?

Available on Continent, provided by the ContinentFunctional extension

Operators

operator ==(Object other) bool
The equality operator.
inherited