SouthernAsia class final
Represents the Southern Asia region, which includes the countries of Afghanistan, Bangladesh, Bhutan, India, Maldives, Nepal, Pakistan, etc.
This class extends SubRegion and sets its name property to "Southern Asia".
Example:
final southernAsia = SouthernAsia();
print(southernAsia.name); // "Southern Asia"
Constructors
- SouthernAsia()
-
Creates a new SouthernAsia instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited