WesternEurope class final
Represents the Western Europe region, which includes the countries of Austria, Belgium, France, Germany, Netherlands, Switzerland, etc.
This class extends SubRegion and sets its name property to "Western Europe".
Example:
import 'package:sealed_countries/sealed_countries.dart';
void main() {
const westernEurope = WesternEurope();
assert(westernEurope.name == 'Western Europe');
}
Constructors
- WesternEurope()
-
Creates a new WesternEurope instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
{bool short = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited